==> zen-cart-v1.2.0-l10n-jp-5.zip: zen-cart-v1.2.0-l10n-jp-5/admin/includes/languages/japanese/record_artists.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: record_artists.php,v 1.3 2004/11/03 07:24:01 shidairiki Exp $
//
  define('HEADING_TITLE', 'ƥ');
  define('TABLE_HEADING_RECORD_ARTISTS', 'ƥ');
  define('TABLE_HEADING_ACTION', '');
  define('TEXT_NEW_INTRO', 'ƥȤϤƤ');
  define('TEXT_EDIT_INTRO', 'ƥȤƤ');
  define('TEXT_DELETE_INTRO', 'ΥƥȤ˺ޤ?');
  define('TEXT_DELETE_IMAGE', 'ޤ?');
  define('TEXT_RECORD_ARTIST_NAME', 'ƥ̾');
  define('TEXT_RECORD_ARTIST_IMAGE', 'ƥȤβ');
  define('TEXT_RECORD_ARTIST_URL', 'ƥȤWeb');
  define('TEXT_ARTISTS_IMAGE_DIR', 'ǥ쥯ȥ&nbsp;');

  define('TEXT_HEADING_NEW_RECORD_ARTIST', 'ƥ');
  define('TEXT_HEADING_EDIT_RECORD_ARTIST', 'ƥȤɲ');
  define('TEXT_HEADING_DELETE_RECORD_ARTIST', 'ƥȤ');
  define('TEXT_DATE_ADDED', '');
  define('TEXT_LAST_MODIFIED', '');
  define('TEXT_IMAGE_NONEXISTENT', 'ʤ');
  define('TEXT_PRODUCTS', '󥯤줿');
  define('TEXT_DISPLAY_NUMBER_OF_ARTISTS', 'Displaying <strong>%d</strong> to <strong>%d</strong> (of <strong>%d</strong> Recording Artists)');
?>

==> zen-cart-v1.3.0.2-l10n-jp-5.zip: zen-cart-v1.3.0.2-l10n-jp-5/admin/includes/languages/japanese/record_artists.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: record_artists.php 276 2004-09-10 22:35:28Z wilt $
//
  define('HEADING_TITLE', 'ƥ');
  define('TABLE_HEADING_RECORD_ARTISTS', 'ƥ');
  define('TABLE_HEADING_ACTION', '');
  define('TEXT_NEW_INTRO', 'ƥȤϤƤ');
  define('TEXT_EDIT_INTRO', 'ƥȤƤ');
  define('TEXT_DELETE_INTRO', 'ΥƥȤ˺ޤ?');
  define('TEXT_DELETE_IMAGE', 'ޤ?');
  define('TEXT_RECORD_ARTIST_NAME', 'ƥ̾');
  define('TEXT_RECORD_ARTIST_IMAGE', 'ƥȤβ');
  define('TEXT_RECORD_ARTIST_URL', 'ƥȤWeb');
  define('TEXT_ARTISTS_IMAGE_DIR', 'ǥ쥯ȥ&nbsp;');

  define('TEXT_HEADING_NEW_RECORD_ARTIST', 'ƥ');
  define('TEXT_HEADING_EDIT_RECORD_ARTIST', 'ƥȤɲ');
  define('TEXT_HEADING_DELETE_RECORD_ARTIST', 'ƥȤ');
  define('TEXT_DATE_ADDED', '');
  define('TEXT_LAST_MODIFIED', '');
  define('TEXT_IMAGE_NONEXISTENT', 'ʤ');
  define('TEXT_PRODUCTS', '󥯤줿');
  define('TEXT_DISPLAY_NUMBER_OF_ARTISTS', ' <strong>%d</strong>  <strong>%d</strong> ޤǤɽ ( <strong>%d</strong> )');
  define('TEXT_DELETE_PRODUCTS', 'ΥȤȡΥƥȤ˥󥯤ƤƤΥƥ˺ޤ?');
  define('TEXT_DELETE_WARNING_PRODUCTS', '<b>ٹ:</b> %sƥबΥƥȤ˥󥯤Ƥޤ!');
?>
